@@ -1,11 +1,10 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2014-12-20 00:41:39 mtw>
+# Last changed Time-stamp: <2015-01-27 16:10:51 mtw>
 
 package Bio::ViennaNGS::Tutorial;
 
-use 5.12.0;
 use Exporter;
-use version; our $VERSION = qv('0.12_07');
+use version; our $VERSION = qv('0.12_13');
 use strict;
 use warnings;
 
@@ -132,9 +131,10 @@ __END__
          }
          close(KMER);
     }>
+
 =cut
 
-=head1 
+=head2 MEME
 
     In a second approach we run MEME to retrieve the 20 most over-represented motifs of length 8.
     C<meme hg19_highexpressed.ext50_fromStart_10_downstream.fa -oc MEME_hg19_highexpressed.ext50_fromStart_10_downstream.fa -w 8 -dna -maxsize 1000000000 -nmotifs 20>
