@@ -1,11 +1,10 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-01-26 01:14:12 mtw>
+# Last changed Time-stamp: <2015-01-27 16:56:46 mtw>
 
 package Bio::ViennaNGS::Util;
 
-use 5.12.0;
 use Exporter;
-use version; our $VERSION = qv('0.12_11');
+use version; our $VERSION = qv('0.12_13');
 use strict;
 use warnings;
 use Data::Dumper;
@@ -232,6 +231,7 @@ sub extend_chain{
   my $r	    = $_[3];
   my $u     = $_[4];
   my $d     = $_[5];
+  my $this_function = (caller(0))[3];
 
   ##return a new chain with extended coordinates
   my $extendchain = $chain -> clone();
@@ -301,7 +301,7 @@ sub extend_chain{
       }
     }
     else{
-      die "Something wrong here!\n";
+      croak "ERROR [$this_function] Something wrong here!\n";
     }
     $feature->start($start);
     $feature->end($end);
@@ -312,7 +312,9 @@ sub extend_chain{
 
 sub parse_bed6{
   my $bedfile = shift;
-  open (my $Bed, "<:gzip(autopop)",$bedfile) or die "$!";
+  my $this_function = (caller(0))[3];
+  open (my $Bed, "<:gzip(autopop)",$bedfile) or 
+    croak "ERROR [$this_function] $!";
   my @featurelist; ## This will become a FeatureChain
   while(<$Bed>){
     ### This should be done by FeatureIO
@@ -353,28 +355,29 @@ sub fetch_chrom_sizes{
   my $this_function = (caller(0))[3];
 
   my $test_fetchChromSizes = can_run('fetchChromSizes') or
-    say "ERROR [$this_function] fetchChromSizes utility not found";
+    croak "ERROR [$this_function] fetchChromSizes utility not found";
 
   my $cmd = "fetchChromSizes $species";
-  my( $success, $error_message, $full_buf, $stdout_buf, $stderr_buf ) = run(command => $cmd, verbose => 0);
+  my( $success, $error_message, $full_buf, $stdout_buf, $stderr_buf ) = 
+    run(command => $cmd, verbose => 0);
   if ($success){
     @chromsize = @{$stdout_buf};
   }
   else{
-    print STDERR "Using UCSCs fetchChromSizes failed, trying alternative mysql fetch!\n";
+    carp "WARN [$this_function] Using UCSCs fetchChromSizes failed, trying alternative mysql fetch!\n";
     my $test_fetchChromSizes = can_run('mysql') or
-      die "ERROR [$this_function] mysql utility not found";
+      croak "ERROR [$this_function] mysql utility not found";
     $cmd = "mysql --user=genome --host=genome-mysql.cse.ucsc.edu -A -e \"select chrom, size from $species.chromInfo\"";  ### Alternative to UCSC fetchChromSizes, has mysql dependency
-    my( $success, $error_message, $full_buf, $stdout_buf, $stderr_buf )  = run(command => $cmd, verbose => 0);
+    my( $success, $error_message, $full_buf, $stdout_buf, $stderr_buf ) =
+      run(command => $cmd, verbose => 0);
     if ($success){
       @chromsize = @{$stdout_buf};
     }
     else{
-      print STDERR "ERROR [$this_function] External command call unsuccessful\n";
-      print STDERR "ERROR: this is what the command printed:\n";
+      carp "ERROR [$this_function] External command call unsuccessful\n";
+      carp "ERROR [$this_function] this is what the command printed:\n";
       print join "", @$full_buf;
-      croak $!;
-      die "Fetching of chromosome sizes failed, please either download fetchChromSizes from the UCSC script collection, or install mysql!\n";
+      confess "Fetching of chromosome sizes failed, please either download fetchChromSizes from the UCSC script collection, or install mysql!\n";
     }
   }
 
@@ -533,7 +536,7 @@ L<BEDtools|https://github.com/arq5x/bedtools2> on your system.
 Copyright (C) 2015 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.12.4 or,
+it under the same terms as Perl itself, either Perl version 5.10.0 or,
 at your option, any later version of Perl 5 you may have available.
 
 This software is distributed in the hope that it will be useful, but
